@@ -1,6 +1,5 @@
 import enum
 import hashlib
-import os
 from types import MappingProxyType
 from typing import Any, Dict, List, Union
 
@@ -9,6 +8,7 @@ from cognite.air.constants import (
     AIR_ALERT_EVENTS_FIELD_SUBTYPE,
     AIR_EVENTS_FIELD_SUBTYPE,
     AIR_EVENTS_FIELD_TYPE,
+    AIR_LOCAL_TESTING_ERROR_MESSAGE,
     EVENT_ASSET_IDS,
     EVENT_DATA_SET_ID,
     EVENT_DATA_SET_IDS,
@@ -18,7 +18,7 @@ from cognite.air.constants import (
     EVENT_TYPE,
     AIREventMeta,
 )
-from cognite.air.utils import is_string_truthy, valfilter, valmap
+from cognite.air.utils import air_data_set_id, is_string_truthy, valfilter, valmap
 from cognite.client.data_classes import Event, EventList
 
 
@@ -86,7 +86,7 @@ class AIREventsAPI(BaseAPIClient):
                 **meta,
                 **self.air_event_required_meta,
                 AIREventMeta.original_model_version: self._config.model_version_stripped,
-                AIREventMeta.project_name: os.getenv("COGNITE_PROJECT"),
+                AIREventMeta.project_name: self._config.client.config.project,
                 AIREventMeta.skip_notification: str(not notification),
                 AIREventMeta.acknowledged: str(not notification),
                 AIREventMeta.show: str(meta.get(AIREventMeta.show, True)),
@@ -148,6 +148,15 @@ class AIREventsAPI(BaseAPIClient):
             raise TypeError(f"Expected single (or list of) Event object(s) ({Event})")
 
         self._make_events_air_compatible_inplace(items, is_alert=is_alert)
+        if self._config.local_testing and not self._config.dev_write_back:
+            raise ValueError(AIR_LOCAL_TESTING_ERROR_MESSAGE)
+        if self._config.dev_write_back:
+            for item in items:
+                item.asset_ids = None
+                item.data_set_id = air_data_set_id(self._config.client, "AIR")
+        else:
+            for item in items:
+                item.data_set_id = self._config.data_set_id
         return self.client.events.create(items[0] if single_item else items)
 
     def create(self, event: Union[Event, List[Event]]) -> Union[Event, EventList]:
