@@ -194,9 +194,7 @@ class AlertCreator:
 
         # close events
         events_to_be_updated, new_events = self._close_event(
-            open_alerts,
-            merged_events,
-            end=end_point,
+            open_alerts, merged_events, end_point, notification_message
         )
         # check if events need to be updated and update
         if len(events_to_be_updated) > 0:
@@ -259,6 +257,7 @@ class AlertCreator:
         existing_events: Union[EventList, List[Event]],
         new_events: List[List[int]],
         end: int,
+        notification: str,
     ) -> Tuple[List[Event], List[List[int]]]:
         """`Identified open Events and check with current events if they should be closed. Manipulates new
             event if overlaps with open Event.`_
@@ -270,6 +269,7 @@ class AlertCreator:
             end (int): The last timestamp to consider.
             min_length_of_alert (int): The minimum length of an alert until which it should be considered.
             merge_period (int): When events should be merged together.
+            notification (str): A string that is going to be sent to the end user and visible in the Front End
 
         Returns:
             Tuple[List[Event], List[List[int]]]: A tuple with a list of open (or maybe now, closed) alerts and a
@@ -290,12 +290,38 @@ class AlertCreator:
         if len(existing_open_events) == 0:
             return [], new_events
 
+        # try to close open events with a different notification message
+        open_events_with_different_notification = list(
+            filter(
+                lambda e: e.metadata is not None and e.metadata.get(MTD_NOTIFICATION_MESSAGE) != notification,
+                existing_open_events,
+            )
+        )
+        events_to_be_closed = []
+        if len(open_events_with_different_notification):
+            for open_event in open_events_with_different_notification:
+                event_end = self._retrieve_event_end(open_event)
+                open_event = self._set_event_end_time_and_show(open_event, end, event_end)
+                events_to_be_closed.append(open_event)
+
+        # only keep existing open events with the same notification message
+        existing_open_events = list(
+            filter(
+                lambda e: e.metadata is None or e.metadata.get(MTD_NOTIFICATION_MESSAGE) == notification,
+                existing_open_events,
+            )
+        )
+
+        if len(existing_open_events) == 0:
+            return events_to_be_closed, new_events
+
         # if there are no new events, try to close existing ones
         if len(new_events) == 0:
             for existing_open_event in existing_open_events:
                 event_end = self._retrieve_event_end(existing_open_event)
                 existing_open_event = self._set_event_end_time_and_show(existing_open_event, end, event_end)
-            return existing_open_events, []
+                events_to_be_closed.append(existing_open_event)
+            return events_to_be_closed, []
         for existing_open_event in existing_open_events:
             for i, new_event in enumerate(new_events):
                 event_end = self._retrieve_event_end(existing_open_event)
@@ -315,7 +341,8 @@ class AlertCreator:
             # when end time in metadata is smaller than end - merge period, set end time to metadata end time
             final_event_end = self._retrieve_event_end(existing_open_event)
             existing_open_event = self._set_event_end_time_and_show(existing_open_event, end, final_event_end)
-        return existing_open_events, remaining_new_events
+            events_to_be_closed.append(existing_open_event)
+        return events_to_be_closed, remaining_new_events
 
     def _can_existing_event_be_prolonged(self, event_end: int, new_event: List[int]) -> bool:
 
