@@ -7,12 +7,15 @@ from cognite.air._events_api import AIREventsAPI
 from cognite.air._time_series_api import AIRTimeSeriesAPI
 from cognite.air._utils import (
     get_local_testing,
+    path_to_yaml,
     retrieve_backfilling,
     retrieve_field_definitions,
+    retrieve_local_testing,
     retrieve_model_name,
     retrieve_model_version,
 )
 from cognite.air.constants import (
+    AIR_DATA_DEV_WRITE_BACK,
     AIR_TYPES,
     LEGAL_FIELD_TYPES,
     MA_FIELD_META_FIELDS,
@@ -28,6 +31,18 @@ from cognite.client.data_classes import Asset, TimeSeries
 
 
 class AIRClient:
+    """The AIRClient.
+        For local testing pass all fields of the model specified in the config.yaml,
+        as well as the name of the model (folder name) and the path to the config.yaml.
+        If the test run should write back to Cognite Data Fusion also pass in `"dev": "True"`
+
+    Args:
+        data (Dict): Dictionary.
+        client (CogniteClient): CogniteClient
+        secrets (Dict): Secrets.
+
+    """
+
     def __init__(self, data: Dict[str, Any], client: CogniteClient, secrets: Dict[str, Any], debug: bool = False):
         del secrets  # Unused for now (required in function signature)
         self._testing = get_local_testing(data)
@@ -51,18 +66,20 @@ class AIRClient:
                 data_fields_defs=self.create_data_field_dct(model_asset.metadata.get(MA_FIELD_META_FIELDS)),
                 model_name=model_asset.name,
                 model_version=model_version,
+                local_testing=False,
+                dev_write_back=False,
             )
 
         else:
-            model_version = retrieve_model_version()
+            model_version = retrieve_model_version(data)
             sa_ext_id = "ScheduleAssetTestExtId"
-            model_name = retrieve_model_name()
+            model_name = retrieve_model_name(data)
             fake_data_set_id = 123
             fake_schedule_asset_id = 123
             fake_backfill_completed = data.get("backfill_completed", "False")
             fake_backfilled_until = data.get("backfilled_until", "0")
 
-            if is_string_truthy(retrieve_backfilling()) and is_string_truthy(data.get("backfilling")):
+            if is_string_truthy(retrieve_backfilling(data)) and is_string_truthy(data.get("backfilling")):
                 backfilling_asset = self.create_fake_backfilling_asset(
                     model_name,
                     fake_schedule_asset_id,
@@ -72,17 +89,19 @@ class AIRClient:
                     fake_backfilled_until,
                     model_version,
                 )
-
+            yaml_path = path_to_yaml(data)
             self._config = AIRClientConfig(
                 client=client,
                 data_set_id=fake_data_set_id,
-                schedule_asset=Asset(),
+                schedule_asset=Asset(metadata={"dashboardId": "dashboard123", "systemId": "system123"}),
                 schedule_asset_id=fake_schedule_asset_id,
                 schedule_asset_ext_id=sa_ext_id,
                 data_fields=data,
-                data_fields_defs=self.create_data_field_dct(retrieve_field_definitions()),
+                data_fields_defs=self.create_data_field_dct(retrieve_field_definitions(yaml_path)),
                 model_name=model_name,
                 model_version=model_version,
+                local_testing=True,
+                dev_write_back=retrieve_local_testing(data, AIR_DATA_DEV_WRITE_BACK, False),
             )
         self.events = AIREventsAPI(self._config)
         self.time_series = AIRTimeSeriesAPI(self._config)
@@ -115,6 +134,13 @@ class AIRClient:
     def schedule_asset_ext_id(self):
         return self._config.schedule_asset_ext_id
 
+    @property
+    def schedule_external_id(self):
+        """Retrieve the unique external ID of the underlying schedule. Helpful when creating Time Series with unique
+        external IDs.
+        """
+        return self._config.schedule_asset_ext_id
+
     @property
     def model_name(self):
         return self._config.model_name
